searchNodes=[{"doc":"Dynamic search and selection component for LiveView. The LiveSelect input is rendered by calling the live_select/3 function and passing it a form and the name of the input. LiveSelect creates a text input field in which the user can type text, and a hidden input field that will contain the value of the selected option. As the text changes, LiveSelect will render a dropdown below the text input containing the matching options, which the user can then select. Selection can happen either using the keyboard, by navigating the options with the arrow keys and then pressing enter, or by clicking an option with the mouse. Whenever an option is selected, LiveSelect will trigger a standard phx-change event in the form. See the &quot;Examples&quot; section below for details on how to handle the event. After an option has been selected, the selection can be undone by clicking on text field. Reacting to user's input Whenever the user types something in the text input, LiveSelect sends a LiveSelect.ChangeMsg.t/0 message to your LiveView. The message has a text property containing the current text entered by the user, and a field property with the name of the LiveSelect input field. The LiveView's job is to handle_info/2 the message and then call update_options/2 to update the dropdown's content with the new set of selectable options. See the &quot;Examples&quot; section below for details. Styling You can use the style option in live_select/3 to control which style will be used by default. Currently supported values are :daisyui (default) or :none (no predefined styles). Support for vanilla Tailwind styles is planned for the future. LiveSelect can style the following elements: The outer container of the component The text field The text field when an option has been selected The dropdown with the options The active option the user navigated to using the arrow keys For each of these components there is a {component}_class and for some a {component}_extra_class option, which can be used to either override or extend the default CSS classes for the component. You can't use both options together: use {component}_class to completely override the default classes, or use {component}_extra_class to extend the default. The following table shows the default styles for each component and the options you can use to adjust its CSS classes. Component Default daisyUI classes class override option class extend option outer container &quot;dropdown&quot; container_class container_extra_class text field &quot;input input-bordered&quot; text_input_class text_input_extra_class text field selected &quot;input-primary text-primary&quot; text_input_selected_class dropdown &quot;dropdown-content menu menu-compact shadow rounded-box&quot; dropdown_class dropdown_extra_class active option &quot;active&quot; active_option_class For example, if you want to show a full-width LiveSelect component with a secondary color for the dropdown background and active options with a warning background, you can do this: live_select ( form , field , container_extra_class : &quot;w-full&quot; , text_input_extra_class : &quot;w-full&quot; , dropdown_extra_class : &quot;w-full bg-secondary&quot; , active_option_class : &quot;bg-warning&quot; ) Result: Examples Here's an example that describes all the moving parts in detail. The user can search for cities. The LiveSelect main form input is called city_search . When a city is selected, the coordinates of that city will be the value of the form input. Then name of the selected city is available in the text input field named city_search_text_input . Template: &lt; . form for = { :my_form } let = { f } phx - change = &quot;change&quot; &gt; &lt; % = live_select f , :city_search % &gt; &lt; / . form &gt; LiveView: import LiveSelect @impl true def handle_info ( % LiveSelect.ChangeMsg { } = change_msg , socket ) do cities = City . search ( change_msg . text ) # cities could be: # [ {&quot;city name 1&quot;, [lat_1, long_1]}, {&quot;city name 2&quot;, [lat_2, long_2]}, ... ] # # but it could also be (no coordinates in this case): # [ &quot;city name 1&quot;, &quot;city name 2&quot;, ... ] # # or: # [ [label: &quot;city name 1&quot;, value: [lat_1, long_1]], [label: &quot;city name 2&quot;, value: [lat_2, long_2]], ... ] # # or even: # [&quot;city name 1&quot;: [lat_1, long_1], &quot;city name 2&quot;: [lat_2, long_2]] update_options ( change_msg , cities ) { :noreply , socket } end @impl true def handle_event ( &quot;change&quot; , %{ &quot;my_form&quot; =&gt; %{ &quot;city_search_text_input&quot; =&gt; city_name , &quot;city_search&quot; =&gt; city_coords } } , socket ) do IO . puts ( &quot;You selected city \#{ city_name } located at: \#{ city_coords } &quot; ) { :noreply , socket } end Multiple LiveSelect inputs in the same LiveView If you have multiple LiveSelect inputs in the same LiveView, you can distinguish them based on the input field. For example: Template: &lt; . form for = { :my_form } let = { f } phx - change = &quot;change&quot; &gt; &lt; % = live_select f , :city_search % &gt; &lt; % = live_select f , :album_search % &gt; &lt; / . form &gt; LiveView: @impl true def handle_info ( % LiveSelect.ChangeMsg { } = change_msg , socket ) do options = case change_msg . field do :city_search -&gt; City . search ( change_msg . text ) :album_search -&gt; Album . search ( change_msg . text ) end update_options ( change_msg , options ) { :noreply , socket } end","ref":"LiveSelect.html","title":"LiveSelect","type":"module"},{"doc":"Renders a LiveSelect input in a form with a given field name. LiveSelect renders a hidden input with name field which contains the selected option. The visible text input field will have the name \#{field}_text_input . Opts: disabled - set this to a truthy value to disable the input field placeholder - placeholder text for the input field debounce - number of milliseconds to wait after the last keystroke before sending a LiveSelect.ChangeMsg.t/0 message. Defaults to 100ms. search_term_min_length - the minimum length of text in the search field that will trigger an update of the dropdown. It has to be a positive integer. Defaults to 3. style - either :daisyui for daisyui styling (default) or :none for no styling. See the &quot;Styles&quot; section above. container_class - See the &quot;Styles&quot; section above for this and the following options. container_extra_class text_input_class text_input_extra_class text_input_selected_class dropdown_class dropdown_extra_class active_option_class","ref":"LiveSelect.html#live_select/3","title":"LiveSelect.live_select/3","type":"function"},{"doc":"Updates a LiveSelect component with new options. change_msg must be the LiveSelect.ChangeMsg.t/0 originally sent by the LiveSelect, and options is the new list of options that will be used to fill the dropdown. Each option will be assigned a label, which will be shown in the dropdown, and a value, which will be the value of the LiveSelect input when the option is selected. options can be any enumerable of the following elements: atoms, strings or numbers : In this case, each element will be both label and value for the option tuples : {label, value} corresponding to label and value for the option maps : %{label: label, value: value} keywords : [label: label, value: value] This means you can use maps and keyword lists to pass the list of options, for example: %{ Red : 1 , Yellow : 2 , Green : 3 } Will result in 3 options with labels :Red , :Yellow , :Green and values 1, 2, and 3. Note that the option values, if they are not strings, will be JSON-encoded. Your LiveView will receive this JSON-encoded version in the phx-change and phx-submit events.","ref":"LiveSelect.html#update_options/2","title":"LiveSelect.update_options/2","type":"function"},{"doc":"LiveSelect.ChangeMsg","ref":"LiveSelect.ChangeMsg.html","title":"LiveSelect.ChangeMsg","type":"module"},{"doc":"Message sent by LiveSelect components in response to text entered by the user in the text input field","ref":"LiveSelect.ChangeMsg.html#t:t/0","title":"LiveSelect.ChangeMsg.t/0","type":"type"},{"doc":"Dynamic search and selection component for LiveView. LiveSelect is a LiveView component that implements a search and selection field with content provided dynamically by your application. It comes with reasonable default styles that use DaisyUI . The default styles can be either extended or completely overridden.","ref":"README.md.html","title":"Readme","type":"extras"},{"doc":"To install, add this to your dependencies: [ { :live_select , &quot;~&gt; 0.1.0&quot; } ]","ref":"README.md.html#installation","title":"Readme - Installation","type":"extras"},{"doc":"LiveSelect relies on Javascript hooks to work. You need to add LiveSelect 's hooks to your live socket. In your app.js file: import live_select from &quot;live_select&quot; // if you don &#39; t have any other hooks : let liveSocket = new LiveSocket ( &quot;/live&quot; , Socket , { params : { _csrf_token : csrfToken } , hooks : live_select } ) // if you have other hooks : const hooks = { MyHook : { // ... } , ... live_select } let liveSocket = new LiveSocket ( &quot;/live&quot; , Socket , { params : { _csrf_token : csrfToken } , hooks } )","ref":"README.md.html#javascript-hooks","title":"Readme - Javascript Hooks","type":"extras"},{"doc":"For the time being, LiveSelect supports 2 styling options: styling with daisyUI or custom styling. The choice of styling is controlled using the style option in LiveSelect.live_select/3 . Support for vanilla Tailwind styles is planned for the future. If you use daisyUI styles, you need to install daisyUI. If you're already using Tailwind, this is as simple as adding an additional plugin to your tailwind.config.js Moreover, in order for Tailwind to see the daisyUI classes used by LiveSelect , you need to add one of the following lines to the content section in your tailwind.config.js : module . exports = { content : [ // ... &#39;../deps/live_select/lib/live_select/component.*ex&#39; &lt;- - for a standalone app &#39;../../../deps/live_select/lib/live_select/component.*ex&#39; &lt;- - for an umbrella app ] // .. } (Notice the different paths for a standalone or umbrella app) That's it! Now your LiveSelect component will use pre-configured daisyUI styles.","ref":"README.md.html#styling","title":"Readme - Styling","type":"extras"},{"doc":"The repository includes a showcase app you can use to play around with the different options and parameters for LiveSelect . To start the showcase app, simply run: mix setup PORT = 4001 mix phx . server from within the cloned repository. The app will be available at http://localhost:4001 . The showcase app shows the messages and events that your LiveView receives. For each event or message, the app shows the function head of the callback that your LiveView needs to implement in order to handle the event. This allows you to quickly copy and paste the function definition into your live view. Note that the showcase app uses the following styling options: [ container_extra_class : &quot;w-full&quot; , dropdown_extra_class : &quot;w-full bg-base-200 p-2&quot; , text_input_extra_class : &quot;w-full&quot; ] See live_select/3 for details.","ref":"README.md.html#showcase-app","title":"Readme - Showcase app","type":"extras"},{"doc":"Refer to the online documentation .","ref":"README.md.html#usage","title":"Readme - Usage","type":"extras"},{"doc":"[X] Add package.json to enable import live_select from &quot;live_select&quot; [X] Make sure component classes are included by tailwind [X] Enable custom styling [X] Rename LiveSelect.render to live_select [X] Customizable placeholder [X] Enable configuration of styles in the showcase app [ ] Add support for vanilla tailwind styles [ ] Enable slots to customize the appearance of the options, for example to implement type ahead hints","ref":"README.md.html#todo","title":"Readme - TODO","type":"extras"},{"doc":"","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"raise if class and extra_class options are used in invalid combinations ( https://github.com/maxmarcon/live_select/issues/2 ) Bugfixes route server events to the right live select component using the component id ( https://github.com/maxmarcon/live_select/issues/1 )","ref":"changelog.html#0-1-4-2022-09-20","title":"Changelog - 0.1.4 (2022-09-20)","type":"extras"},{"doc":"rename LiveSelect.update/2 to LiveSelect.update_options/2 add debounce option add search delay option to showcase app JSON-encode option values before assigning them to the hidden input field add LiveSelect.ChangeMsg struct to be used as change message","ref":"changelog.html#0-1-3-2022-08-12","title":"Changelog - 0.1.3 (2022-08-12)","type":"extras"},{"doc":"Disable input field via options Placeholder text via options Improve docs and showcase app Remove setting component id via options Bugfixes Use atoms as field names, because strings are not accepted by Ecto forms","ref":"changelog.html#0-1-2-2022-08-10","title":"Changelog - 0.1.2 (2022-08-10)","type":"extras"},{"doc":"Remove all colors from default daisyui styles Improve styling of showcase app Improve docs Remove the msg_prefix option in favor of change_msg","ref":"changelog.html#0-1-1-2022-08-09","title":"Changelog - 0.1.1 (2022-08-09)","type":"extras"},{"doc":"First version 🎉","ref":"changelog.html#0-1-0-2022-08-09","title":"Changelog - 0.1.0 (2022-08-09)","type":"extras"}]